#!/usr/bin/python
# -*- coding: UTF-8 -*-

############################################################################
##                                                                        ##
## Bookkun - Manage your ebooks.                                          ##
##                                                                        ##
## Copyright (C) 2012  Fabien Loison <flo AT flogisoft DOT com>           ##
##                                                                        ##
## This program is free software: you can redistribute it and/or modify   ##
## it under the terms of the GNU General Public License as published by   ##
## the Free Software Foundation, either version 3 of the License, or      ##
## (at your option) any later version.                                    ##
##                                                                        ##
## This program is distributed in the hope that it will be useful,        ##
## but WITHOUT ANY WARRANTY; without even the implied warranty of         ##
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          ##
## GNU General Public License for more details.                           ##
##                                                                        ##
## You should have received a copy of the GNU General Public License      ##
## along with this program.  If not, see <http://www.gnu.org/licenses/>.  ##
##                                                                        ##
############################################################################


class BookkunException(Exception):
    """Base class for all Bookkun exceptions.

    Keyword Args:
        errmsg -- An optional error message.
    """

    def __init__(self, errmsg=""):
        """The constructor."""
        Exception.__init__(self, errmsg)


class ResourceNotFound(BookkunException):
    """Exception raised when a resource can't be found.

    Keyword Args:
        resource_name -- The name of the resource."""

    def __init__(self, resource_name=""):
        """The constructor."""
        if resource_name:
            errmsg = "Resource not found: '%s'" % resource_name
        else:
            errmsg = "Resource not found"
        BookkunException.__init__(self, errmsg)


class UnknownResourceType(BookkunException):
    """Exception raised when a resource type is unknown.

    Keyword Args:
        resource_name -- The name of the resource."""

    def __init__(self, resource_name=""):
        """The constructor."""
        if resource_name:
            errmsg = "Unknown resource type: '%s'" % resource_name
        else:
            errmsg = "Unknown resource type"
        BookkunException.__init__(self, errmsg)
