#!/usr/bin/python
# -*- coding: UTF-8 -*-

############################################################################
##                                                                        ##
## Bookkun - Manage your ebooks.                                          ##
##                                                                        ##
## Copyright (C) 2012  Fabien Loison <flo AT flogisoft DOT com>           ##
##                                                                        ##
## This program is free software: you can redistribute it and/or modify   ##
## it under the terms of the GNU General Public License as published by   ##
## the Free Software Foundation, either version 3 of the License, or      ##
## (at your option) any later version.                                    ##
##                                                                        ##
## This program is distributed in the hope that it will be useful,        ##
## but WITHOUT ANY WARRANTY; without even the implied warranty of         ##
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          ##
## GNU General Public License for more details.                           ##
##                                                                        ##
## You should have received a copy of the GNU General Public License      ##
## along with this program.  If not, see <http://www.gnu.org/licenses/>.  ##
##                                                                        ##
############################################################################


from gi.repository import Gtk
from gi.repository import WebKit

from bookkun.helpers import get_resource


class MainWindow(object):

    """The Bookkun main window."""

    def __init__(self):
        """The constructor."""
        # Dark Theme (TODO: THEME)
        Gtk.Settings().get_default() \
            .set_property("gtk-application-prefer-dark-theme", True)
        # Gtk Builder
        builder = Gtk.Builder()
        builder.add_from_file(get_resource("main.glade"))
        # Main Window
        window = builder.get_object("win_main")
        window.connect("delete-event", Gtk.main_quit)
        # Toolbar
        builder.get_object("toolbar").get_style_context().add_class(
                Gtk.STYLE_CLASS_PRIMARY_TOOLBAR)
        # Webview
        self._webview = WebKit.WebView()
        builder.get_object("scrwin_webview").add(self._webview)
        self._webview.show()

    def update_webview(self, html_string):
        """Update the content of the webview.

        Args:
            html_string -- A string containing the HTML page.
        """
        self._webview.load_html_string(html_string, "")


WIN_MAIN = MainWindow()
